adaptive_linear_layout library

Classes

FlexLinearLayout
A layout widget that automatically switches between Row and Column based on screen orientation and layout preference.

Enums

LayoutPreference
Specifies the layout direction to use in portrait mode.
ReverseDirection
Specifies if and how the child order should be reversed.